@@ -1,6 +1,7 @@
 import io
 import logging
 import multiprocessing as mp
+import os
 import time
 import typing as t
 from contextlib import contextmanager
@@ -593,7 +594,7 @@ class SQLAlchemyDatabase:
         data: pl.DataFrame,
         mode: t.Literal["RAISE", "IGNORE", "UPDATE"],
         *,
-        chunk_size: int = 1_000_000,
+        chunk_size: int = 1_000_000_000,
         returning_id: bool = False,
     ) -> pl.DataFrame | None:
         """
@@ -787,6 +788,16 @@ class SQLAlchemyDatabase:
         if not chunks:
             return None
 
+        logger.info(f"Created {len(chunks)} chunks for processing")
+
+        # Test multiprocessing capability first
+        try:
+            import multiprocessing
+            mp.set_start_method('spawn', force=True)  # Force spawn method for better compatibility
+            logger.info(f"Multiprocessing start method set to: {mp.get_start_method()}")
+        except Exception as e:
+            logger.warning(f"Could not set multiprocessing start method: {e}")
+
         # Get connection parameters for workers to recreate engines
         # Need to extract full connection info including password
         engine_url = self.engine.url
@@ -827,14 +838,12 @@ class SQLAlchemyDatabase:
             )
 
         all_id_maps = []
-        all_worker_times = []
 
         # Use multiprocessing Pool with imap_unordered for real-time updates
         with mp.Pool(processes=num_workers) as pool:
             # Submit all chunks to workers and process results as they complete
             for result in pool.imap_unordered(worker_func, chunks):
-                batch_size, id_df, worker_times = result
-                all_worker_times.append(worker_times)
+                batch_size, id_df = result
                 if show_progress:
                     progress_bar.update(batch_size)
                 if returning_id and id_df is not None:
@@ -843,28 +852,6 @@ class SQLAlchemyDatabase:
         if show_progress:
             progress_bar.close()
 
-        # Aggregate and log performance statistics
-        if all_worker_times:
-            # Calculate averages across all workers
-            avg_times = {}
-            for key in all_worker_times[0].keys():
-                avg_times[key] = sum(worker[key] for worker in all_worker_times) / len(all_worker_times)
-            
-            total_avg_time = sum(avg_times.values())
-            total_rows = data.height
-            
-            logger.info(
-                f"Parallel COPY Performance Breakdown (average per worker) for {total_rows:,} rows with {num_workers} workers:\n"
-                f"  CSV generation:   {avg_times['csv_gen']:.3f}s ({avg_times['csv_gen']/total_avg_time*100:.1f}%)\n"
-                f"  COPY to temp:     {avg_times['copy_data']:.3f}s ({avg_times['copy_data']/total_avg_time*100:.1f}%)\n"
-                f"  INSERT upsert:    {avg_times['insert']:.3f}s ({avg_times['insert']/total_avg_time*100:.1f}%)\n"
-                f"  Fetch IDs:        {avg_times['fetch_ids']:.3f}s ({avg_times['fetch_ids']/total_avg_time*100:.1f}%)\n"
-                f"  Temp table ops:   {avg_times['temp_table_ops']:.3f}s ({avg_times['temp_table_ops']/total_avg_time*100:.1f}%)\n"
-                f"  Avg worker time:  {total_avg_time:.3f}s\n"
-                f"  Workers used:     {len(all_worker_times)}\n"
-                f"  Parallel efficiency: {len(all_worker_times) * total_avg_time:.1f}s total worker time"
-            )
-
         if returning_id and all_id_maps:
             return pl.concat(all_id_maps)
         return None
@@ -946,20 +933,17 @@ def _copy_worker_static(
     table: str,
     cols: list[str],
     returning_id: bool,
-) -> tuple[int, pl.DataFrame | None, dict[str, float]]:
+) -> tuple[int, pl.DataFrame | None]:
     """
     Static worker function for parallel COPY operations.
     This function recreates its own database connection from the connection URL.
 
     Returns:
-        tuple: (batch_size, id_dataframe_or_none, timing_stats)
+        tuple: (batch_size, id_dataframe_or_none)
 
     """
     offset, batch = chunk_data
     batch_size = batch.height
-    
-    # Performance tracking
-    worker_times = {"csv_gen": 0, "copy_data": 0, "insert": 0, "fetch_ids": 0, "temp_table_ops": 0}
 
     # Create new engine and connection for this worker
     worker_engine = create_engine(connection_url)
@@ -989,37 +973,26 @@ def _copy_worker_static(
         non_id_cols = [c for c in cols if c.upper() != "ID"]
         non_id_col_list = ", ".join(f'"{c}"' for c in non_id_cols)
 
-        # Time temp table creation
-        start = time.time()
         cursor.execute(
             f'CREATE TEMP TABLE "{temp_table}" AS SELECT {non_id_col_list} FROM "{table}" WHERE FALSE'  # noqa: S608
         )
-        worker_times["temp_table_ops"] += time.time() - start
 
-        # 1) Time CSV generation and COPY data into staging
-        start = time.time()
+        # 1) COPY data into staging
         buf = io.StringIO()
         batch.write_csv(buf)
         buf.seek(0)
-        worker_times["csv_gen"] += time.time() - start
-        
-        start = time.time()
         cursor.copy_expert(f'COPY "{temp_table}" ({non_id_col_list}) FROM STDIN WITH CSV HEADER', buf)
-        worker_times["copy_data"] += time.time() - start
 
-        # 2) Time INSERT FROM staging into real table
-        start = time.time()
+        # 2) INSERT FROM staging into real table
         insert_sql = (
             f'INSERT INTO "{table}" ({non_id_col_list}) SELECT {non_id_col_list} FROM "{temp_table}" '  # noqa: S608
             + on_conflict
         )
         cursor.execute(insert_sql)
-        worker_times["insert"] += time.time() - start
 
-        # 3) Time ID fetching
+        # 3) Optionally retrieve IDs
         id_df = None
         if returning_id:
-            start = time.time()
             buf_out = io.StringIO()
             # Build SELECT clause with explicit aliases
             select_list = ", ".join(['r."ID" AS "ID"', *[f't."{c}" AS "{c}"' for c in pks]])
@@ -1027,23 +1000,18 @@ def _copy_worker_static(
             cursor.copy_expert(copy_sql, buf_out)
             buf_out.seek(0)
             id_df = pl.read_csv(buf_out)
-            worker_times["fetch_ids"] += time.time() - start
 
-        # 4) Time cleanup
-        start = time.time()
+        # 4) Clean up temp table
         cursor.execute(f'DROP TABLE IF EXISTS "{temp_table}"')
-        worker_times["temp_table_ops"] += time.time() - start
 
         # Commit this worker's transaction
         raw_conn.commit()
 
     except Exception:
         raw_conn.rollback()
-        # Use print for worker logging since logger may not work across processes
-        print(f"Worker error for offset {offset}")
         raise
     else:
-        return (batch_size, id_df, worker_times)
+        return (batch_size, id_df)
     finally:
         cursor.close()
         raw_conn.close()
